@@ -97,16 +97,13 @@ static void max_aspect_window(Display *display, Window window, int w, int h)
 		       (h - tmph)/2,
 		       tmpw, 
 		       tmph);
-     XSync(display, False);
 }
 
 __inline
 static void fill_window(Display *display, Window window, int w, int h)
 {
      D("New size: %dx%d+%d+%d (of %dx%d)\n", w, h, 0, 0, w, h);
-
      XMoveResizeWindow(display, window, 0, 0, w, h);
-     XSync(display, False);
 }
 
 static void adjust_window_size(void)
@@ -136,7 +133,6 @@ static void adjust_window_size(void)
 static int place_window(void)
 {
      XWMHints *leader_change;
-     int i;
 
      if (!victim) return 0;
      if (!WINDOW) return 0;
@@ -156,17 +152,7 @@ static int place_window(void)
      }
      
      D("Reparenting window %x into %x\n", victim, WINDOW);
-
-     /* Multiple XReparentWindow() are necessary on some X servers. */
-     for (i = 0; i < 30; i++)
-     {
-	  XReparentWindow (display, victim, WINDOW, 0, 0);
-	  XSync(display, False);
-     }
-
-     /* XMapWindow() is necessary under OpenWindows. */
-     XMapWindow(display, victim);
-     XSync(display, False);
+     XReparentWindow(display, victim, WINDOW, 0, 0);
 
      D("place_window() done\n");
 
@@ -204,7 +190,7 @@ static int my_strcmp(char *windowname, char *name)
      case '*':
 	  return strncasecmp(name+1, windowname, strlen(name)-1);
      default:
-	  return strncasecmp(name, windowname, strlen(name));
+	  return !strstr(windowname, name);
      }
 }
 
@@ -275,10 +261,10 @@ static Window winrecur(Window from, int depth, char *name)
      return (Window)0;
 }
 
-static int setup_swallow()
+static int setup_display()
 {
      char *displayname = getenv("DISPLAY");
-     D("Setting up X data (%s)\n", displayname);
+     D("setup_display(%s)\n", displayname);
 
      XSetErrorHandler(error_handler);
 
@@ -291,17 +277,8 @@ static int setup_swallow()
      D("display=%x\n", display);
      D("WINDOW=%x\n", WINDOW);
      D("rootwin=%x\n", wattr.root);
-
-     XSelectInput(display, WINDOW,
-		  SubstructureNotifyMask |
-		  SubstructureRedirectMask);
      
-     XSelectInput(display, wattr.root, 
-		  SubstructureNotifyMask);
-     
-     XSync(display, False);
-     
-     D("Done Setting up X data for root=%x\n", wattr.root);
+     D("setup_display() done\n");
 
      return 0;
 }
@@ -359,6 +336,7 @@ static Bool AllXEventsPredicate(Display *dpy, XEvent *ev, char *arg)
      return True;
 }
 
+
 static void check_x_events(void)
 {
      XEvent ev;
@@ -397,6 +375,7 @@ static void check_x_events(void)
 	       {
 	       case UnmapNotify:
 		    D("UNMAPNOTIFY\n");
+		    XMapWindow(display, victim);
 		    break;
 	    
 	       case MapNotify:
@@ -409,7 +388,7 @@ static void check_x_events(void)
 		    if (ev.xreparent.parent == WINDOW)
 		    {
 			 D("REPARENT NOTIFY to the right window\n");
-			 XMapWindow (display, victim);
+			 XMapWindow(display, victim);
 			 adjust_window_size();
 		    } else {
 			 D("REPARENT NOTIFY to some other window!\n");
@@ -502,10 +481,6 @@ static void check_all_events()
 	  if (FD_ISSET(pipe_fd, &fds))
 	       check_pipe_fd_events();
      }
-     else
-     {
-	  D("SELECT ERROR\n");
-     }
 
      if (display)
      {
@@ -610,12 +585,18 @@ int main(int argc, char **argv)
 	       argv[3] = NULL;
 	  }
 	  
-	  /* Has to be done before forking */
-	  if (setup_swallow())
+	  if (setup_display())
 	  {
-	       D("setup_swallow() failed\n");
+	       D("setup_display() failed\n");
 	       flags &=~ H_SWALLOW;
 	  }
+	  else
+	  {
+               /* Has to be done before forking */
+	       XSelectInput(display, WINDOW, SubstructureNotifyMask | SubstructureRedirectMask);
+	       XSelectInput(display, wattr.root, SubstructureNotifyMask);
+	       XSync(display, False);
+	  }
 
 	  if ((pid = fork()) == -1)
 	       exit(EX_UNAVAILABLE);
@@ -626,7 +607,9 @@ int main(int argc, char **argv)
 	       XSelectInput(display, wattr.root, 0);
 	       D("Running %s\n", command);
 	       run_app(argv);
-	  } else {
+	  }
+	  else
+	  {
 	       D("Waiting for pid=%d\n", pid);
 	       handle_app(pid);
 	       D("Wait done (repeats=%d, loops=%d)\n", repeats, loops);
