@@ -87,7 +87,6 @@ static char *controller_fname;
 static struct handle *first_handle;
 static struct handle **prev_handlep;
 static struct handle **handlep;
-static char tempfile;
 
 /*****************************************************************************
  * Wrapper for fork() which handles some magic needed to prevent netscape
@@ -1109,27 +1108,14 @@ NPError NPP_NewStream(NPP instance,
 	 && strncasecmp(stream->url, "mailbox:", 8))
      {
 	  *stype = NP_NORMAL;
-	  tempfile = 0;
 	  new_child(instance, stream->url);
-     } else {
-	  *stype = NP_ASFILEONLY;
-	  tempfile = 1;
+	  return NPERR_GENERIC_ERROR;
      }
+
+     *stype = NP_ASFILEONLY;
      return NPERR_NO_ERROR;
 }
 
-/*****************************************************************************
- * Return 0 to avoid the browser to download data.
- *****************************************************************************/
-int32 NPP_WriteReady(NPP instance, NPStream *stream)
-{
-     D("WriteReady\n");
-
-     if (!instance) return 0;
-     if (!tempfile) return 0;
-     return 0x7fffffff;
-}
-
 /*****************************************************************************
  * Called after NPP_NewStream if *stype = NP_ASFILEONLY.
  *****************************************************************************/
@@ -1222,3 +1208,11 @@ int32 NPP_Write(NPP instance,
      D("Write\n");
      return len;
 }
+
+int32 NPP_WriteReady(NPP instance, NPStream *stream)
+{
+     D("WriteReady\n");
+
+     if (!instance) return 0;
+     return MAXINT;
+}
